﻿IF OBJECT_ID(N'[__EFMigrationsHistory]') IS NULL
BEGIN
    CREATE TABLE [__EFMigrationsHistory] (
        [MigrationId] nvarchar(150) NOT NULL,
        [ProductVersion] nvarchar(32) NOT NULL,
        CONSTRAINT [PK___EFMigrationsHistory] PRIMARY KEY ([MigrationId])
    );
END;
GO

BEGIN TRANSACTION;
GO

CREATE TABLE [Admin] (
    [Id] uniqueidentifier NOT NULL,
    [Account] nvarchar(100) NOT NULL,
    [Password] nvarchar(50) NOT NULL,
    CONSTRAINT [PK_Admin] PRIMARY KEY ([Id])
);
GO

CREATE TABLE [Blocked] (
    [Id] uniqueidentifier NOT NULL,
    [Key] nvarchar(50) NOT NULL,
    [IsIPAddress] bit NOT NULL,
    [BlockedTime] datetime2 NOT NULL,
    [Forever] bit NOT NULL,
    [Description] nvarchar(500) NULL,
    CONSTRAINT [PK_Blocked] PRIMARY KEY ([Id])
);
GO

CREATE TABLE [ClientException] (
    [Id] uniqueidentifier NOT NULL,
    [ReportTime] datetime2 NOT NULL,
    [IP] nvarchar(15) NOT NULL,
    [SiteCode] nvarchar(100) NULL,
    [StaffId] uniqueidentifier NULL,
    [Message] nvarchar(500) NULL,
    [Detail] nvarchar(max) NULL,
    CONSTRAINT [PK_ClientException] PRIMARY KEY ([Id])
);
GO

CREATE TABLE [CustomerUILanguage] (
    [Id] uniqueidentifier NOT NULL,
    [Name] nvarchar(50) NULL,
    [Code] nvarchar(20) NULL,
    [OrderNumber] int NOT NULL,
    CONSTRAINT [PK_CustomerUILanguage] PRIMARY KEY ([Id])
);
GO

CREATE TABLE [Domain] (
    [Id] uniqueidentifier NOT NULL,
    [Name] nvarchar(100) NOT NULL,
    [ContactPerson] nvarchar(50) NULL,
    [Email] nvarchar(200) NULL,
    [Cellphone] nvarchar(11) NULL,
    [MaxSiteCount] int NOT NULL,
    [MaxStaffCount] int NOT NULL,
    [CreateTime] datetime2 NOT NULL,
    [Removed] bit NOT NULL,
    [StaffLastLoginTime] datetime2 NULL,
    [StaffLastLoginIPAddress] nvarchar(max) NULL,
    [StaffLastLoginLocation] nvarchar(max) NULL,
    CONSTRAINT [PK_Domain] PRIMARY KEY ([Id])
);
GO

CREATE TABLE [OfficialInformation] (
    [Id] uniqueidentifier NOT NULL,
    [Type] nvarchar(50) NULL,
    [Title] nvarchar(200) NULL,
    [Url] nvarchar(1000) NULL,
    CONSTRAINT [PK_OfficialInformation] PRIMARY KEY ([Id])
);
GO

CREATE TABLE [PublishedClientVersion] (
    [Id] uniqueidentifier NOT NULL,
    [Type] nvarchar(10) NULL,
    [Version] nvarchar(50) NULL,
    [Url] nvarchar(1000) NULL,
    CONSTRAINT [PK_PublishedClientVersion] PRIMARY KEY ([Id])
);
GO

CREATE TABLE [SocketClientConnectLog] (
    [Id] uniqueidentifier NOT NULL,
    [IP] nvarchar(15) NOT NULL,
    [ConnectedTime] datetime2 NOT NULL,
    [DisconnectedTime] datetime2 NULL,
    [ReceivedPackageCount] int NOT NULL,
    [Connected] bit NOT NULL,
    [Questionable] bit NOT NULL,
    [QuestionableDescription] nvarchar(500) NULL,
    CONSTRAINT [PK_SocketClientConnectLog] PRIMARY KEY ([Id])
);
GO

CREATE TABLE [TabooWords] (
    [Id] uniqueidentifier NOT NULL,
    [Words] nvarchar(50) NULL,
    CONSTRAINT [PK_TabooWords] PRIMARY KEY ([Id])
);
GO

CREATE TABLE [Dictionary] (
    [Id] uniqueidentifier NOT NULL,
    [Name] nvarchar(100) NOT NULL,
    [Key] nvarchar(100) NOT NULL,
    [DomainId] uniqueidentifier NOT NULL,
    CONSTRAINT [PK_Dictionary] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_Dictionary_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE NO ACTION
);
GO

CREATE TABLE [Organization] (
    [Id] uniqueidentifier NOT NULL,
    [ParentId] uniqueidentifier NULL,
    [IdPath] nvarchar(max) NOT NULL,
    [Name] nvarchar(100) NOT NULL,
    [NumericalOrder] int NOT NULL,
    [Removed] bit NOT NULL,
    [DomainId] uniqueidentifier NOT NULL,
    CONSTRAINT [PK_Organization] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_Organization_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE NO ACTION,
    CONSTRAINT [FK_Organization_Organization_ParentId] FOREIGN KEY ([ParentId]) REFERENCES [Organization] ([Id])
);
GO

CREATE TABLE [Role] (
    [Id] uniqueidentifier NOT NULL,
    [Name] nvarchar(100) NOT NULL,
    [DomainId] uniqueidentifier NOT NULL,
    CONSTRAINT [PK_Role] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_Role_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE NO ACTION
);
GO

CREATE TABLE [Site] (
    [Id] uniqueidentifier NOT NULL,
    [Code] nvarchar(100) NOT NULL,
    [Name] nvarchar(100) NOT NULL,
    [SiteLoginAuthorization] int NOT NULL,
    [CreateTime] datetime2 NOT NULL,
    [Removed] bit NOT NULL,
    [StaffLastLoginTime] datetime2 NULL,
    [StaffLastLoginIPAddress] nvarchar(100) NULL,
    [StaffLastLoginLocation] nvarchar(200) NULL,
    [DomainId] uniqueidentifier NOT NULL,
    CONSTRAINT [PK_Site] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_Site_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE NO ACTION
);
GO

CREATE TABLE [DictionaryItem] (
    [Id] uniqueidentifier NOT NULL,
    [DictionaryId] uniqueidentifier NOT NULL,
    [Text] nvarchar(100) NOT NULL,
    [Value] int NOT NULL,
    [NumericalOrder] int NOT NULL,
    [DomainId] uniqueidentifier NOT NULL,
    CONSTRAINT [PK_DictionaryItem] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_DictionaryItem_Dictionary_DictionaryId] FOREIGN KEY ([DictionaryId]) REFERENCES [Dictionary] ([Id]) ON DELETE CASCADE,
    CONSTRAINT [FK_DictionaryItem_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE NO ACTION
);
GO

CREATE TABLE [Staff] (
    [Id] uniqueidentifier NOT NULL,
    [OrganizationId] uniqueidentifier NOT NULL,
    [Account] nvarchar(100) NOT NULL,
    [Password] nvarchar(50) NOT NULL,
    [Name] nvarchar(100) NOT NULL,
    [NickName] nvarchar(100) NULL,
    [Gender] int NOT NULL,
    [Email] nvarchar(100) NULL,
    [QQ] nvarchar(100) NULL,
    [Telphone] nvarchar(50) NULL,
    [Cellphone] nvarchar(50) NULL,
    [Remark] nvarchar(500) NULL,
    [CreateTime] datetime2 NOT NULL,
    [DomainAdmin] bit NOT NULL,
    [Removed] bit NOT NULL,
    [Online] bit NOT NULL,
    [LastLoginTime] datetime2 NULL,
    [LastLoginIPAddress] nvarchar(max) NULL,
    [LastLoginLocation] nvarchar(max) NULL,
    [DomainId] uniqueidentifier NOT NULL,
    CONSTRAINT [PK_Staff] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_Staff_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE NO ACTION,
    CONSTRAINT [FK_Staff_Organization_OrganizationId] FOREIGN KEY ([OrganizationId]) REFERENCES [Organization] ([Id]) ON DELETE CASCADE
);
GO

CREATE TABLE [RoleAuthorization] (
    [Id] uniqueidentifier NOT NULL,
    [RoleId] uniqueidentifier NOT NULL,
    [AuthorizationKey] nvarchar(100) NULL,
    [DomainId] uniqueidentifier NOT NULL,
    CONSTRAINT [PK_RoleAuthorization] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_RoleAuthorization_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE NO ACTION,
    CONSTRAINT [FK_RoleAuthorization_Role_RoleId] FOREIGN KEY ([RoleId]) REFERENCES [Role] ([Id]) ON DELETE CASCADE
);
GO

CREATE TABLE [CustomerCategory] (
    [Id] uniqueidentifier NOT NULL,
    [SiteId] uniqueidentifier NOT NULL,
    [Name] nvarchar(100) NOT NULL,
    [Color] nvarchar(10) NOT NULL,
    [DomainId] uniqueidentifier NOT NULL,
    CONSTRAINT [PK_CustomerCategory] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_CustomerCategory_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE NO ACTION,
    CONSTRAINT [FK_CustomerCategory_Site_SiteId] FOREIGN KEY ([SiteId]) REFERENCES [Site] ([Id]) ON DELETE NO ACTION
);
GO

CREATE TABLE [CustomerCount] (
    [Id] uniqueidentifier NOT NULL,
    [SiteId] uniqueidentifier NOT NULL,
    [Location] nvarchar(100) NOT NULL,
    [Count] int NOT NULL,
    [DomainId] uniqueidentifier NOT NULL,
    CONSTRAINT [PK_CustomerCount] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_CustomerCount_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE CASCADE,
    CONSTRAINT [FK_CustomerCount_Site_SiteId] FOREIGN KEY ([SiteId]) REFERENCES [Site] ([Id]) ON DELETE CASCADE
);
GO

CREATE TABLE [CustomerImportentLevel] (
    [Id] uniqueidentifier NOT NULL,
    [SiteId] uniqueidentifier NOT NULL,
    [Name] nvarchar(100) NOT NULL,
    [Color] nvarchar(10) NOT NULL,
    [DomainId] uniqueidentifier NOT NULL,
    CONSTRAINT [PK_CustomerImportentLevel] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_CustomerImportentLevel_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE NO ACTION,
    CONSTRAINT [FK_CustomerImportentLevel_Site_SiteId] FOREIGN KEY ([SiteId]) REFERENCES [Site] ([Id]) ON DELETE NO ACTION
);
GO

CREATE TABLE [OpenApiCaller] (
    [Id] uniqueidentifier NOT NULL,
    [SiteId] uniqueidentifier NOT NULL,
    [Name] nvarchar(100) NULL,
    [IPWhiteList] nvarchar(500) NULL,
    [SecretKey] nvarchar(100) NULL,
    [CallbackApiUrl] nvarchar(2000) NULL,
    [Enable] bit NOT NULL,
    [CreateTime] datetime2 NOT NULL,
    [DomainId] uniqueidentifier NOT NULL,
    CONSTRAINT [PK_OpenApiCaller] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_OpenApiCaller_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE NO ACTION,
    CONSTRAINT [FK_OpenApiCaller_Site_SiteId] FOREIGN KEY ([SiteId]) REFERENCES [Site] ([Id]) ON DELETE NO ACTION
);
GO

CREATE TABLE [RobotExternalApiSettings] (
    [Id] uniqueidentifier NOT NULL,
    [SiteId] uniqueidentifier NOT NULL,
    [Url] nvarchar(max) NULL,
    [DomainId] uniqueidentifier NOT NULL,
    CONSTRAINT [PK_RobotExternalApiSettings] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_RobotExternalApiSettings_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE CASCADE,
    CONSTRAINT [FK_RobotExternalApiSettings_Site_SiteId] FOREIGN KEY ([SiteId]) REFERENCES [Site] ([Id]) ON DELETE CASCADE
);
GO

CREATE TABLE [RobotItem] (
    [Id] uniqueidentifier NOT NULL,
    [SiteId] uniqueidentifier NOT NULL,
    [ParentId] uniqueidentifier NULL,
    [IdPath] nvarchar(max) NOT NULL,
    [Language] nvarchar(20) NOT NULL,
    [Title] nvarchar(100) NOT NULL,
    [Content] nvarchar(4000) NULL,
    [NumericalOrder] bigint NOT NULL,
    [DomainId] uniqueidentifier NOT NULL,
    CONSTRAINT [PK_RobotItem] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_RobotItem_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE NO ACTION,
    CONSTRAINT [FK_RobotItem_RobotItem_ParentId] FOREIGN KEY ([ParentId]) REFERENCES [RobotItem] ([Id]),
    CONSTRAINT [FK_RobotItem_Site_SiteId] FOREIGN KEY ([SiteId]) REFERENCES [Site] ([Id]) ON DELETE CASCADE
);
GO

CREATE TABLE [RobotSettings] (
    [Id] uniqueidentifier NOT NULL,
    [SiteId] uniqueidentifier NOT NULL,
    [Mode] int NOT NULL,
    [DomainId] uniqueidentifier NOT NULL,
    CONSTRAINT [PK_RobotSettings] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_RobotSettings_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE CASCADE,
    CONSTRAINT [FK_RobotSettings_Site_SiteId] FOREIGN KEY ([SiteId]) REFERENCES [Site] ([Id]) ON DELETE CASCADE
);
GO

CREATE TABLE [SiteSettings_AutoGreetings] (
    [Id] uniqueidentifier NOT NULL,
    [SiteId] uniqueidentifier NOT NULL,
    [WebChatAutoExpand] int NOT NULL,
    [ShowGreetings] int NOT NULL,
    [Greetings] nvarchar(max) NULL,
    [DomainId] uniqueidentifier NOT NULL,
    CONSTRAINT [PK_SiteSettings_AutoGreetings] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_SiteSettings_AutoGreetings_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE CASCADE,
    CONSTRAINT [FK_SiteSettings_AutoGreetings_Site_SiteId] FOREIGN KEY ([SiteId]) REFERENCES [Site] ([Id]) ON DELETE CASCADE
);
GO

CREATE TABLE [SiteSettings_CustomerFillInFieldBeforeStart] (
    [Id] uniqueidentifier NOT NULL,
    [SiteId] uniqueidentifier NOT NULL,
    [CustomerFillInFieldBeforeStart1] bit NOT NULL,
    [CustomerFillInFieldBeforeStart1_MultipleRow] bit NOT NULL,
    [CustomerFillInFieldBeforeStart1_Required] bit NOT NULL,
    [CustomerFillInFieldBeforeStart1_Name] nvarchar(50) NULL,
    [CustomerFillInFieldBeforeStart1_Title] nvarchar(max) NULL,
    [CustomerFillInFieldBeforeStart1_Description] nvarchar(max) NULL,
    [CustomerFillInFieldBeforeStart2] bit NOT NULL,
    [CustomerFillInFieldBeforeStart2_MultipleRow] bit NOT NULL,
    [CustomerFillInFieldBeforeStart2_Required] bit NOT NULL,
    [CustomerFillInFieldBeforeStart2_Name] nvarchar(50) NULL,
    [CustomerFillInFieldBeforeStart2_Title] nvarchar(max) NULL,
    [CustomerFillInFieldBeforeStart2_Description] nvarchar(max) NULL,
    [CustomerFillInFieldBeforeStart3] bit NOT NULL,
    [CustomerFillInFieldBeforeStart3_MultipleRow] bit NOT NULL,
    [CustomerFillInFieldBeforeStart3_Required] bit NOT NULL,
    [CustomerFillInFieldBeforeStart3_Name] nvarchar(50) NULL,
    [CustomerFillInFieldBeforeStart3_Title] nvarchar(max) NULL,
    [CustomerFillInFieldBeforeStart3_Description] nvarchar(max) NULL,
    [DomainId] uniqueidentifier NOT NULL,
    CONSTRAINT [PK_SiteSettings_CustomerFillInFieldBeforeStart] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_SiteSettings_CustomerFillInFieldBeforeStart_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE CASCADE,
    CONSTRAINT [FK_SiteSettings_CustomerFillInFieldBeforeStart_Site_SiteId] FOREIGN KEY ([SiteId]) REFERENCES [Site] ([Id]) ON DELETE CASCADE
);
GO

CREATE TABLE [SiteSettings_CustomerUILanguage] (
    [Id] uniqueidentifier NOT NULL,
    [SiteId] uniqueidentifier NOT NULL,
    [DefaultLanguage] nvarchar(20) NULL,
    [ReplacementLanguage] nvarchar(20) NULL,
    [AllowCustomerSwitchLanguage] bit NOT NULL,
    [AllLanguagesAvailable] bit NOT NULL,
    [AllowedLanguages] nvarchar(1000) NULL,
    [DomainId] uniqueidentifier NOT NULL,
    CONSTRAINT [PK_SiteSettings_CustomerUILanguage] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_SiteSettings_CustomerUILanguage_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE CASCADE,
    CONSTRAINT [FK_SiteSettings_CustomerUILanguage_Site_SiteId] FOREIGN KEY ([SiteId]) REFERENCES [Site] ([Id]) ON DELETE CASCADE
);
GO

CREATE TABLE [SiteSettings_FakeCustomerWaitingQueue] (
    [Id] uniqueidentifier NOT NULL,
    [SiteId] uniqueidentifier NOT NULL,
    [Enabled] bit NOT NULL,
    [MinQueueCount] int NOT NULL,
    [MaxQueueCount] int NOT NULL,
    [DomainId] uniqueidentifier NOT NULL,
    CONSTRAINT [PK_SiteSettings_FakeCustomerWaitingQueue] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_SiteSettings_FakeCustomerWaitingQueue_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE CASCADE,
    CONSTRAINT [FK_SiteSettings_FakeCustomerWaitingQueue_Site_SiteId] FOREIGN KEY ([SiteId]) REFERENCES [Site] ([Id]) ON DELETE CASCADE
);
GO

CREATE TABLE [SiteSettings_LeaveMessageContentTemplate] (
    [Id] uniqueidentifier NOT NULL,
    [SiteId] uniqueidentifier NOT NULL,
    [ContentTemplate] nvarchar(max) NULL,
    [DomainId] uniqueidentifier NOT NULL,
    CONSTRAINT [PK_SiteSettings_LeaveMessageContentTemplate] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_SiteSettings_LeaveMessageContentTemplate_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE CASCADE,
    CONSTRAINT [FK_SiteSettings_LeaveMessageContentTemplate_Site_SiteId] FOREIGN KEY ([SiteId]) REFERENCES [Site] ([Id]) ON DELETE CASCADE
);
GO

CREATE TABLE [SiteSettings_MiniWebChat] (
    [Id] uniqueidentifier NOT NULL,
    [SiteId] uniqueidentifier NOT NULL,
    [Position] int NOT NULL,
    [HorizontalMargin] int NOT NULL,
    [VerticalMargin] int NOT NULL,
    [CollapsedStyle] int NOT NULL,
    [CollapsedBarPosition] int NOT NULL,
    [BarHorizontalMargin] int NOT NULL,
    [BarVerticalMargin] int NOT NULL,
    [BarImageWhenStaffOnline] nvarchar(1000) NULL,
    [BarImageWhenNoStaffOnline] nvarchar(1000) NULL,
    [CollapsedIconPosition] int NOT NULL,
    [IconHorizontalMargin] int NOT NULL,
    [IconVerticalMargin] int NOT NULL,
    [IconImageWhenStaffOnline] nvarchar(1000) NULL,
    [IconImageWhenNoStaffOnline] nvarchar(1000) NULL,
    [TitleWhenStaffOnline] nvarchar(2000) NULL,
    [TitleWhenNoStaffOnline] nvarchar(2000) NULL,
    [DomainId] uniqueidentifier NOT NULL,
    CONSTRAINT [PK_SiteSettings_MiniWebChat] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_SiteSettings_MiniWebChat_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE CASCADE,
    CONSTRAINT [FK_SiteSettings_MiniWebChat_Site_SiteId] FOREIGN KEY ([SiteId]) REFERENCES [Site] ([Id]) ON DELETE CASCADE
);
GO

CREATE TABLE [SiteSettings_Misc] (
    [Id] uniqueidentifier NOT NULL,
    [SiteId] uniqueidentifier NOT NULL,
    [DomainAddress] nvarchar(500) NULL,
    [LoadingMode] int NOT NULL,
    [IPLocationLanguage] nvarchar(10) NULL,
    [StoreVisitSession] bit NOT NULL,
    [DomainId] uniqueidentifier NOT NULL,
    CONSTRAINT [PK_SiteSettings_Misc] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_SiteSettings_Misc_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE CASCADE,
    CONSTRAINT [FK_SiteSettings_Misc_Site_SiteId] FOREIGN KEY ([SiteId]) REFERENCES [Site] ([Id]) ON DELETE CASCADE
);
GO

CREATE TABLE [SiteSettings_Translation] (
    [Id] uniqueidentifier NOT NULL,
    [SiteId] uniqueidentifier NOT NULL,
    [AutoTranslate] bit NOT NULL,
    [ContentLanguage] nvarchar(20) NULL,
    [TranslateContentToLanguage] nvarchar(20) NULL,
    [DomainId] uniqueidentifier NOT NULL,
    CONSTRAINT [PK_SiteSettings_Translation] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_SiteSettings_Translation_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE CASCADE,
    CONSTRAINT [FK_SiteSettings_Translation_Site_SiteId] FOREIGN KEY ([SiteId]) REFERENCES [Site] ([Id]) ON DELETE CASCADE
);
GO

CREATE TABLE [SiteSettings_WebChatMisc] (
    [Id] uniqueidentifier NOT NULL,
    [SiteId] uniqueidentifier NOT NULL,
    [FeedbackWhenEndWebChat] int NOT NULL,
    [ShowHistory] bit NOT NULL,
    [SendImageFile] bit NOT NULL,
    [SendImageFileMaxLength] int NOT NULL,
    [DomainId] uniqueidentifier NOT NULL,
    CONSTRAINT [PK_SiteSettings_WebChatMisc] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_SiteSettings_WebChatMisc_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE CASCADE,
    CONSTRAINT [FK_SiteSettings_WebChatMisc_Site_SiteId] FOREIGN KEY ([SiteId]) REFERENCES [Site] ([Id]) ON DELETE CASCADE
);
GO

CREATE TABLE [SiteSettings_WebChatOpeningGreetings] (
    [Id] uniqueidentifier NOT NULL,
    [SiteId] uniqueidentifier NOT NULL,
    [Greetings] nvarchar(max) NULL,
    [DomainId] uniqueidentifier NOT NULL,
    CONSTRAINT [PK_SiteSettings_WebChatOpeningGreetings] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_SiteSettings_WebChatOpeningGreetings_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE CASCADE,
    CONSTRAINT [FK_SiteSettings_WebChatOpeningGreetings_Site_SiteId] FOREIGN KEY ([SiteId]) REFERENCES [Site] ([Id]) ON DELETE CASCADE
);
GO

CREATE TABLE [SiteSettings_WebChatStyle] (
    [Id] uniqueidentifier NOT NULL,
    [SiteId] uniqueidentifier NOT NULL,
    [ChatWindowTitle] nvarchar(2000) NULL,
    [LogoImage] nvarchar(1000) NULL,
    [BackgroundImage] nvarchar(1000) NULL,
    [LogoAndTitleDisplayMode] int NOT NULL,
    [WebChatTheme] int NOT NULL,
    [EnableThemeSwitching] bit NOT NULL,
    [DomainId] uniqueidentifier NOT NULL,
    CONSTRAINT [PK_SiteSettings_WebChatStyle] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_SiteSettings_WebChatStyle_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE CASCADE,
    CONSTRAINT [FK_SiteSettings_WebChatStyle_Site_SiteId] FOREIGN KEY ([SiteId]) REFERENCES [Site] ([Id]) ON DELETE CASCADE
);
GO

CREATE TABLE [SiteSettings_WebLeaveMessage] (
    [Id] uniqueidentifier NOT NULL,
    [SiteId] uniqueidentifier NOT NULL,
    [Notice] nvarchar(max) NULL,
    [DomainId] uniqueidentifier NOT NULL,
    CONSTRAINT [PK_SiteSettings_WebLeaveMessage] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_SiteSettings_WebLeaveMessage_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE CASCADE,
    CONSTRAINT [FK_SiteSettings_WebLeaveMessage_Site_SiteId] FOREIGN KEY ([SiteId]) REFERENCES [Site] ([Id]) ON DELETE CASCADE
);
GO

CREATE TABLE [SiteSettings_WebPagePlugIn] (
    [Id] uniqueidentifier NOT NULL,
    [SiteId] uniqueidentifier NOT NULL,
    [PlugIn1] bit NOT NULL,
    [PlugIn1_Title] nvarchar(50) NULL,
    [PlugIn1_Url] nvarchar(1000) NULL,
    [PlugIn2] bit NOT NULL,
    [PlugIn2_Title] nvarchar(50) NULL,
    [PlugIn2_Url] nvarchar(1000) NULL,
    [PlugIn3] bit NOT NULL,
    [PlugIn3_Title] nvarchar(50) NULL,
    [PlugIn3_Url] nvarchar(1000) NULL,
    [DomainId] uniqueidentifier NOT NULL,
    CONSTRAINT [PK_SiteSettings_WebPagePlugIn] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_SiteSettings_WebPagePlugIn_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE CASCADE,
    CONSTRAINT [FK_SiteSettings_WebPagePlugIn_Site_SiteId] FOREIGN KEY ([SiteId]) REFERENCES [Site] ([Id]) ON DELETE CASCADE
);
GO

CREATE TABLE [SkillGroup] (
    [Id] uniqueidentifier NOT NULL,
    [SiteId] uniqueidentifier NOT NULL,
    [Name] nvarchar(100) NOT NULL,
    [DisplayNameForCustomer] nvarchar(max) NOT NULL,
    [Remark] nvarchar(500) NULL,
    [NumericalOrder] bigint NOT NULL,
    [DomainId] uniqueidentifier NOT NULL,
    CONSTRAINT [PK_SkillGroup] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_SkillGroup_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE NO ACTION,
    CONSTRAINT [FK_SkillGroup_Site_SiteId] FOREIGN KEY ([SiteId]) REFERENCES [Site] ([Id]) ON DELETE NO ACTION
);
GO

CREATE TABLE [SkillGroupSettings] (
    [Id] uniqueidentifier NOT NULL,
    [SiteId] uniqueidentifier NOT NULL,
    [Enabled] bit NOT NULL,
    [DomainId] uniqueidentifier NOT NULL,
    CONSTRAINT [PK_SkillGroupSettings] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_SkillGroupSettings_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE NO ACTION,
    CONSTRAINT [FK_SkillGroupSettings_Site_SiteId] FOREIGN KEY ([SiteId]) REFERENCES [Site] ([Id]) ON DELETE NO ACTION
);
GO

CREATE TABLE [StaffClientWebPagePlugIn] (
    [Id] uniqueidentifier NOT NULL,
    [SiteId] uniqueidentifier NOT NULL,
    [Enable] bit NOT NULL,
    [Title] nvarchar(50) NULL,
    [Url] nvarchar(2000) NULL,
    [Description] nvarchar(500) NULL,
    [NumericalOrder] bigint NOT NULL,
    [DomainId] uniqueidentifier NOT NULL,
    CONSTRAINT [PK_StaffClientWebPagePlugIn] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_StaffClientWebPagePlugIn_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE CASCADE,
    CONSTRAINT [FK_StaffClientWebPagePlugIn_Site_SiteId] FOREIGN KEY ([SiteId]) REFERENCES [Site] ([Id]) ON DELETE CASCADE
);
GO

CREATE TABLE [FavouriteFile] (
    [Id] uniqueidentifier NOT NULL,
    [StaffId] uniqueidentifier NOT NULL,
    [SiteId] uniqueidentifier NOT NULL,
    [Name] nvarchar(200) NOT NULL,
    [Extension] nvarchar(50) NULL,
    [Size] float NULL,
    [Description] nvarchar(500) NULL,
    [Url] nvarchar(1000) NULL,
    [Shared] bit NOT NULL,
    [CreateTime] datetime2 NOT NULL,
    [DomainId] uniqueidentifier NOT NULL,
    CONSTRAINT [PK_FavouriteFile] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_FavouriteFile_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE CASCADE,
    CONSTRAINT [FK_FavouriteFile_Site_SiteId] FOREIGN KEY ([SiteId]) REFERENCES [Site] ([Id]) ON DELETE CASCADE,
    CONSTRAINT [FK_FavouriteFile_Staff_StaffId] FOREIGN KEY ([StaffId]) REFERENCES [Staff] ([Id]) ON DELETE CASCADE
);
GO

CREATE TABLE [QuicklyReplyCategory] (
    [Id] uniqueidentifier NOT NULL,
    [Name] nvarchar(100) NOT NULL,
    [StaffId] uniqueidentifier NOT NULL,
    [NumericalOrder] bigint NOT NULL,
    [DomainId] uniqueidentifier NOT NULL,
    CONSTRAINT [PK_QuicklyReplyCategory] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_QuicklyReplyCategory_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE NO ACTION,
    CONSTRAINT [FK_QuicklyReplyCategory_Staff_StaffId] FOREIGN KEY ([StaffId]) REFERENCES [Staff] ([Id]) ON DELETE CASCADE
);
GO

CREATE TABLE [RoleStaff] (
    [Id] uniqueidentifier NOT NULL,
    [RoleId] uniqueidentifier NOT NULL,
    [StaffId] uniqueidentifier NOT NULL,
    [DomainId] uniqueidentifier NOT NULL,
    CONSTRAINT [PK_RoleStaff] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_RoleStaff_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE NO ACTION,
    CONSTRAINT [FK_RoleStaff_Role_RoleId] FOREIGN KEY ([RoleId]) REFERENCES [Role] ([Id]) ON DELETE CASCADE,
    CONSTRAINT [FK_RoleStaff_Staff_StaffId] FOREIGN KEY ([StaffId]) REFERENCES [Staff] ([Id]) ON DELETE CASCADE
);
GO

CREATE TABLE [SiteLoginAppointedStaff] (
    [Id] uniqueidentifier NOT NULL,
    [SiteId] uniqueidentifier NOT NULL,
    [StaffId] uniqueidentifier NOT NULL,
    [DomainId] uniqueidentifier NOT NULL,
    CONSTRAINT [PK_SiteLoginAppointedStaff] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_SiteLoginAppointedStaff_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE NO ACTION,
    CONSTRAINT [FK_SiteLoginAppointedStaff_Site_SiteId] FOREIGN KEY ([SiteId]) REFERENCES [Site] ([Id]) ON DELETE CASCADE,
    CONSTRAINT [FK_SiteLoginAppointedStaff_Staff_StaffId] FOREIGN KEY ([StaffId]) REFERENCES [Staff] ([Id]) ON DELETE CASCADE
);
GO

CREATE TABLE [StaffLoginHistory] (
    [Id] uniqueidentifier NOT NULL,
    [StaffId] uniqueidentifier NOT NULL,
    [SiteId] uniqueidentifier NOT NULL,
    [LoginTime] datetime2 NOT NULL,
    [LogoutTime] datetime2 NULL,
    [DurationMinutes] int NULL,
    [IPAddress] nvarchar(max) NULL,
    [Location] nvarchar(max) NULL,
    [SessionCount] int NULL,
    [SentMessageCount] int NULL,
    [ReceivedMessageCount] int NULL,
    [DomainId] uniqueidentifier NOT NULL,
    CONSTRAINT [PK_StaffLoginHistory] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_StaffLoginHistory_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE NO ACTION,
    CONSTRAINT [FK_StaffLoginHistory_Site_SiteId] FOREIGN KEY ([SiteId]) REFERENCES [Site] ([Id]) ON DELETE NO ACTION,
    CONSTRAINT [FK_StaffLoginHistory_Staff_StaffId] FOREIGN KEY ([StaffId]) REFERENCES [Staff] ([Id]) ON DELETE CASCADE
);
GO

CREATE TABLE [StaffPersonalSettings_MobileWebChatOpeningGreetings] (
    [Id] uniqueidentifier NOT NULL,
    [SiteId] uniqueidentifier NOT NULL,
    [StaffId] uniqueidentifier NOT NULL,
    [Greetings] nvarchar(max) NULL,
    [DomainId] uniqueidentifier NOT NULL,
    CONSTRAINT [PK_StaffPersonalSettings_MobileWebChatOpeningGreetings] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_StaffPersonalSettings_MobileWebChatOpeningGreetings_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE CASCADE,
    CONSTRAINT [FK_StaffPersonalSettings_MobileWebChatOpeningGreetings_Site_SiteId] FOREIGN KEY ([SiteId]) REFERENCES [Site] ([Id]) ON DELETE CASCADE,
    CONSTRAINT [FK_StaffPersonalSettings_MobileWebChatOpeningGreetings_Staff_StaffId] FOREIGN KEY ([StaffId]) REFERENCES [Staff] ([Id]) ON DELETE CASCADE
);
GO

CREATE TABLE [StaffPersonalSettings_Remind] (
    [Id] uniqueidentifier NOT NULL,
    [StaffId] uniqueidentifier NOT NULL,
    [NewCustomer_Bubble] bit NOT NULL,
    [NewCustomer_ShowView] bit NOT NULL,
    [NewCustomer_Sound] bit NOT NULL,
    [NewMessage_Bubble] bit NOT NULL,
    [NewMessage_ShowView] bit NOT NULL,
    [NewMessage_Sound] bit NOT NULL,
    [NewSession_Bubble] bit NOT NULL,
    [NewSession_ShowView] bit NOT NULL,
    [NewSession_Sound] bit NOT NULL,
    [DomainId] uniqueidentifier NOT NULL,
    CONSTRAINT [PK_StaffPersonalSettings_Remind] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_StaffPersonalSettings_Remind_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE CASCADE,
    CONSTRAINT [FK_StaffPersonalSettings_Remind_Staff_StaffId] FOREIGN KEY ([StaffId]) REFERENCES [Staff] ([Id]) ON DELETE CASCADE
);
GO

CREATE TABLE [StaffPersonalSettings_WebChatOpeningGreetings] (
    [Id] uniqueidentifier NOT NULL,
    [SiteId] uniqueidentifier NOT NULL,
    [StaffId] uniqueidentifier NOT NULL,
    [Greetings] nvarchar(max) NULL,
    [DomainId] uniqueidentifier NOT NULL,
    CONSTRAINT [PK_StaffPersonalSettings_WebChatOpeningGreetings] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_StaffPersonalSettings_WebChatOpeningGreetings_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE CASCADE,
    CONSTRAINT [FK_StaffPersonalSettings_WebChatOpeningGreetings_Site_SiteId] FOREIGN KEY ([SiteId]) REFERENCES [Site] ([Id]) ON DELETE CASCADE,
    CONSTRAINT [FK_StaffPersonalSettings_WebChatOpeningGreetings_Staff_StaffId] FOREIGN KEY ([StaffId]) REFERENCES [Staff] ([Id]) ON DELETE CASCADE
);
GO

CREATE TABLE [StaffSettings_Operation] (
    [Id] uniqueidentifier NOT NULL,
    [StaffId] uniqueidentifier NOT NULL,
    [DoubleClickVisitCustomerToStartInvite] bit NOT NULL,
    [AutoRemoveOfflineCustomer] bit NOT NULL,
    [AutoRemoveOfflineCustomerMinute] int NOT NULL,
    [AutoTurnStatusIntoLeaving] bit NOT NULL,
    [AutoTurnStatusIntoLeavingMinute] int NOT NULL,
    [DomainId] uniqueidentifier NOT NULL,
    CONSTRAINT [PK_StaffSettings_Operation] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_StaffSettings_Operation_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE NO ACTION,
    CONSTRAINT [FK_StaffSettings_Operation_Staff_StaffId] FOREIGN KEY ([StaffId]) REFERENCES [Staff] ([Id]) ON DELETE CASCADE
);
GO

CREATE TABLE [Customer] (
    [Id] uniqueidentifier NOT NULL,
    [SiteId] uniqueidentifier NOT NULL,
    [Name] nvarchar(100) NOT NULL,
    [Gender] int NOT NULL,
    [CustomerCategoryId] uniqueidentifier NULL,
    [CustomerImportentLevelId] uniqueidentifier NULL,
    [Remark] nvarchar(500) NULL,
    [Blocked] bit NOT NULL,
    [BlockedByStaffId] uniqueidentifier NULL,
    [BlockedTime] datetime2 NULL,
    [ExternalId] nvarchar(50) NULL,
    [ExternalName] nvarchar(50) NULL,
    [ExternalData] nvarchar(2000) NULL,
    [CreatedTime] datetime2 NULL,
    [LastLoginTime] datetime2 NULL,
    [LastLoginIPAddress] nvarchar(max) NULL,
    [LastLoginLocation] nvarchar(max) NULL,
    [LastDialogueTime] datetime2 NULL,
    [AnyDialogue] bit NOT NULL,
    [LastDialogueStaffId] uniqueidentifier NULL,
    [LastDialogueSessionStartType] int NULL,
    [LastSessionMissing] bit NOT NULL,
    [CustomerUILanguage] nvarchar(20) NULL,
    [ContentLanguage] nvarchar(20) NULL,
    [TranslateContentToLanguage] nvarchar(20) NULL,
    [DomainId] uniqueidentifier NOT NULL,
    CONSTRAINT [PK_Customer] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_Customer_CustomerCategory_CustomerCategoryId] FOREIGN KEY ([CustomerCategoryId]) REFERENCES [CustomerCategory] ([Id]),
    CONSTRAINT [FK_Customer_CustomerImportentLevel_CustomerImportentLevelId] FOREIGN KEY ([CustomerImportentLevelId]) REFERENCES [CustomerImportentLevel] ([Id]),
    CONSTRAINT [FK_Customer_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE NO ACTION,
    CONSTRAINT [FK_Customer_Site_SiteId] FOREIGN KEY ([SiteId]) REFERENCES [Site] ([Id]) ON DELETE NO ACTION,
    CONSTRAINT [FK_Customer_Staff_BlockedByStaffId] FOREIGN KEY ([BlockedByStaffId]) REFERENCES [Staff] ([Id]),
    CONSTRAINT [FK_Customer_Staff_LastDialogueStaffId] FOREIGN KEY ([LastDialogueStaffId]) REFERENCES [Staff] ([Id])
);
GO

CREATE TABLE [OpenApiCallLog] (
    [Id] uniqueidentifier NOT NULL,
    [SiteId] uniqueidentifier NOT NULL,
    [OpenApiCallerId] uniqueidentifier NOT NULL,
    [CallTime] datetime2 NOT NULL,
    [IP] nvarchar(50) NULL,
    [Action] nvarchar(500) NULL,
    [InArgs] nvarchar(max) NULL,
    [OutResult] nvarchar(max) NULL,
    [DomainId] uniqueidentifier NOT NULL,
    CONSTRAINT [PK_OpenApiCallLog] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_OpenApiCallLog_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE NO ACTION,
    CONSTRAINT [FK_OpenApiCallLog_OpenApiCaller_OpenApiCallerId] FOREIGN KEY ([OpenApiCallerId]) REFERENCES [OpenApiCaller] ([Id]) ON DELETE CASCADE,
    CONSTRAINT [FK_OpenApiCallLog_Site_SiteId] FOREIGN KEY ([SiteId]) REFERENCES [Site] ([Id]) ON DELETE NO ACTION
);
GO

CREATE TABLE [SkillGroupStaff] (
    [Id] uniqueidentifier NOT NULL,
    [SkillGroupId] uniqueidentifier NOT NULL,
    [StaffId] uniqueidentifier NOT NULL,
    [DomainId] uniqueidentifier NOT NULL,
    CONSTRAINT [PK_SkillGroupStaff] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_SkillGroupStaff_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE NO ACTION,
    CONSTRAINT [FK_SkillGroupStaff_SkillGroup_SkillGroupId] FOREIGN KEY ([SkillGroupId]) REFERENCES [SkillGroup] ([Id]) ON DELETE CASCADE,
    CONSTRAINT [FK_SkillGroupStaff_Staff_StaffId] FOREIGN KEY ([StaffId]) REFERENCES [Staff] ([Id]) ON DELETE CASCADE
);
GO

CREATE TABLE [QuicklyReplyItem] (
    [Id] uniqueidentifier NOT NULL,
    [QuicklyReplyCategoryId] uniqueidentifier NOT NULL,
    [StaffId] uniqueidentifier NOT NULL,
    [NumericalOrder] bigint NOT NULL,
    [Name] nvarchar(100) NOT NULL,
    [Content] nvarchar(1000) NOT NULL,
    [HotKey] nvarchar(50) NULL,
    [DomainId] uniqueidentifier NOT NULL,
    CONSTRAINT [PK_QuicklyReplyItem] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_QuicklyReplyItem_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE NO ACTION,
    CONSTRAINT [FK_QuicklyReplyItem_QuicklyReplyCategory_QuicklyReplyCategoryId] FOREIGN KEY ([QuicklyReplyCategoryId]) REFERENCES [QuicklyReplyCategory] ([Id]) ON DELETE CASCADE
);
GO

CREATE TABLE [Contact] (
    [Id] uniqueidentifier NOT NULL,
    [SiteId] uniqueidentifier NOT NULL,
    [CustomerId] uniqueidentifier NOT NULL,
    [CreatedTime] datetime2 NOT NULL,
    [LatestUpdatedStaffId] uniqueidentifier NOT NULL,
    [LatestUpdateTime] datetime2 NOT NULL,
    [Name] nvarchar(100) NOT NULL,
    [Gender] int NOT NULL,
    [Country] nvarchar(100) NULL,
    [Province] nvarchar(100) NULL,
    [City] nvarchar(100) NULL,
    [Email] nvarchar(100) NULL,
    [QQ] nvarchar(100) NULL,
    [Telphone] nvarchar(50) NULL,
    [Cellphone] nvarchar(50) NULL,
    [Company] nvarchar(100) NULL,
    [Address] nvarchar(200) NULL,
    [Remark] nvarchar(500) NULL,
    [DomainId] uniqueidentifier NOT NULL,
    CONSTRAINT [PK_Contact] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_Contact_Customer_CustomerId] FOREIGN KEY ([CustomerId]) REFERENCES [Customer] ([Id]) ON DELETE CASCADE,
    CONSTRAINT [FK_Contact_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE NO ACTION,
    CONSTRAINT [FK_Contact_Site_SiteId] FOREIGN KEY ([SiteId]) REFERENCES [Site] ([Id]) ON DELETE NO ACTION
);
GO

CREATE TABLE [CustomerWebpageVisitationTrack] (
    [Id] uniqueidentifier NOT NULL,
    [SiteId] uniqueidentifier NOT NULL,
    [CustomerId] uniqueidentifier NOT NULL,
    [Url] nvarchar(1000) NOT NULL,
    [Title] nvarchar(100) NOT NULL,
    [VisitedTime] datetime2 NOT NULL,
    [DomainId] uniqueidentifier NOT NULL,
    CONSTRAINT [PK_CustomerWebpageVisitationTrack] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_CustomerWebpageVisitationTrack_Customer_CustomerId] FOREIGN KEY ([CustomerId]) REFERENCES [Customer] ([Id]) ON DELETE CASCADE,
    CONSTRAINT [FK_CustomerWebpageVisitationTrack_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE NO ACTION,
    CONSTRAINT [FK_CustomerWebpageVisitationTrack_Site_SiteId] FOREIGN KEY ([SiteId]) REFERENCES [Site] ([Id]) ON DELETE NO ACTION
);
GO

CREATE TABLE [LeaveMessage] (
    [Id] uniqueidentifier NOT NULL,
    [SiteId] uniqueidentifier NOT NULL,
    [CustomerId] uniqueidentifier NOT NULL,
    [ExtensionField1] nvarchar(100) NULL,
    [ExtensionField2] nvarchar(100) NULL,
    [ExtensionField3] nvarchar(100) NULL,
    [Name] nvarchar(50) NULL,
    [ContactInformation] nvarchar(100) NULL,
    [Content] nvarchar(500) NULL,
    [Processed] bit NOT NULL,
    [ProcessedRemark] nvarchar(1000) NULL,
    [ProcessedStaffId] uniqueidentifier NULL,
    [CreateTime] datetime2 NOT NULL,
    [ProcessedTime] datetime2 NULL,
    [DomainId] uniqueidentifier NOT NULL,
    CONSTRAINT [PK_LeaveMessage] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_LeaveMessage_Customer_CustomerId] FOREIGN KEY ([CustomerId]) REFERENCES [Customer] ([Id]) ON DELETE CASCADE,
    CONSTRAINT [FK_LeaveMessage_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE NO ACTION,
    CONSTRAINT [FK_LeaveMessage_Site_SiteId] FOREIGN KEY ([SiteId]) REFERENCES [Site] ([Id]) ON DELETE NO ACTION,
    CONSTRAINT [FK_LeaveMessage_Staff_ProcessedStaffId] FOREIGN KEY ([ProcessedStaffId]) REFERENCES [Staff] ([Id])
);
GO

CREATE TABLE [Session] (
    [Id] uniqueidentifier NOT NULL,
    [SiteId] uniqueidentifier NOT NULL,
    [StartTime] datetime2 NOT NULL,
    [EndTime] datetime2 NULL,
    [DurationSeconds] int NULL,
    [StaffId] uniqueidentifier NULL,
    [CustomerId] uniqueidentifier NOT NULL,
    [StartType] int NOT NULL,
    [Interactive] bit NOT NULL,
    [Missing] bit NOT NULL,
    [StaffMessageCount] int NOT NULL,
    [CustomerMessageCount] int NOT NULL,
    [CustomerIP] nvarchar(20) NULL,
    [CustomerIPDistrict] nvarchar(200) NULL,
    [Remark] nvarchar(500) NULL,
    [Taboo] bit NOT NULL,
    [TabooWords] nvarchar(50) NULL,
    [SkillGroupId] uniqueidentifier NULL,
    [CustomerFillInFieldBeforeStart1] nvarchar(100) NULL,
    [CustomerFillInFieldBeforeStart1_Title] nvarchar(100) NULL,
    [CustomerFillInFieldBeforeStart2] nvarchar(100) NULL,
    [CustomerFillInFieldBeforeStart2_Title] nvarchar(100) NULL,
    [CustomerFillInFieldBeforeStart3] nvarchar(100) NULL,
    [CustomerFillInFieldBeforeStart3_Title] nvarchar(100) NULL,
    [FeedbackStar] int NULL,
    [FeedbackContent] nvarchar(500) NULL,
    [DomainId] uniqueidentifier NOT NULL,
    CONSTRAINT [PK_Session] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_Session_Customer_CustomerId] FOREIGN KEY ([CustomerId]) REFERENCES [Customer] ([Id]) ON DELETE CASCADE,
    CONSTRAINT [FK_Session_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE NO ACTION,
    CONSTRAINT [FK_Session_Site_SiteId] FOREIGN KEY ([SiteId]) REFERENCES [Site] ([Id]) ON DELETE NO ACTION,
    CONSTRAINT [FK_Session_SkillGroup_SkillGroupId] FOREIGN KEY ([SkillGroupId]) REFERENCES [SkillGroup] ([Id]) ON DELETE SET NULL,
    CONSTRAINT [FK_Session_Staff_StaffId] FOREIGN KEY ([StaffId]) REFERENCES [Staff] ([Id])
);
GO

CREATE TABLE [DialogMessage] (
    [Id] uniqueidentifier NOT NULL,
    [SiteId] uniqueidentifier NOT NULL,
    [SessionId] uniqueidentifier NOT NULL,
    [Type] int NOT NULL,
    [Content] nvarchar(2000) NULL,
    [Translated] bit NOT NULL,
    [TranslatedContent] nvarchar(max) NULL,
    [ContentLanguage] nvarchar(20) NULL,
    [TranslatedContentLanguage] nvarchar(20) NULL,
    [StaffId] uniqueidentifier NULL,
    [CustomerId] uniqueidentifier NULL,
    [SentBySystem] bit NOT NULL,
    [SentByOpenApi] bit NOT NULL,
    [StaffNickName] nvarchar(100) NULL,
    [SentTime] datetime2 NOT NULL,
    [Taboo] bit NOT NULL,
    [TabooWords] nvarchar(50) NULL,
    [Removed] bit NOT NULL,
    [DomainId] uniqueidentifier NOT NULL,
    CONSTRAINT [PK_DialogMessage] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_DialogMessage_Customer_CustomerId] FOREIGN KEY ([CustomerId]) REFERENCES [Customer] ([Id]),
    CONSTRAINT [FK_DialogMessage_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE NO ACTION,
    CONSTRAINT [FK_DialogMessage_Session_SessionId] FOREIGN KEY ([SessionId]) REFERENCES [Session] ([Id]) ON DELETE CASCADE,
    CONSTRAINT [FK_DialogMessage_Site_SiteId] FOREIGN KEY ([SiteId]) REFERENCES [Site] ([Id]) ON DELETE NO ACTION,
    CONSTRAINT [FK_DialogMessage_Staff_StaffId] FOREIGN KEY ([StaffId]) REFERENCES [Staff] ([Id])
);
GO

CREATE INDEX [IX_Contact_CustomerId] ON [Contact] ([CustomerId]);
GO

CREATE INDEX [IX_Contact_DomainId] ON [Contact] ([DomainId]);
GO

CREATE INDEX [IX_Contact_SiteId] ON [Contact] ([SiteId]);
GO

CREATE INDEX [IX_Customer_BlockedByStaffId] ON [Customer] ([BlockedByStaffId]);
GO

CREATE INDEX [IX_Customer_CustomerCategoryId] ON [Customer] ([CustomerCategoryId]);
GO

CREATE INDEX [IX_Customer_CustomerImportentLevelId] ON [Customer] ([CustomerImportentLevelId]);
GO

CREATE INDEX [IX_Customer_DomainId] ON [Customer] ([DomainId]);
GO

CREATE INDEX [IX_Customer_LastDialogueStaffId] ON [Customer] ([LastDialogueStaffId]);
GO

CREATE INDEX [IX_Customer_SiteId] ON [Customer] ([SiteId]);
GO

CREATE INDEX [IX_CustomerCategory_DomainId] ON [CustomerCategory] ([DomainId]);
GO

CREATE INDEX [IX_CustomerCategory_SiteId] ON [CustomerCategory] ([SiteId]);
GO

CREATE INDEX [IX_CustomerCount_DomainId] ON [CustomerCount] ([DomainId]);
GO

CREATE INDEX [IX_CustomerCount_SiteId] ON [CustomerCount] ([SiteId]);
GO

CREATE INDEX [IX_CustomerImportentLevel_DomainId] ON [CustomerImportentLevel] ([DomainId]);
GO

CREATE INDEX [IX_CustomerImportentLevel_SiteId] ON [CustomerImportentLevel] ([SiteId]);
GO

CREATE INDEX [IX_CustomerWebpageVisitationTrack_CustomerId] ON [CustomerWebpageVisitationTrack] ([CustomerId]);
GO

CREATE INDEX [IX_CustomerWebpageVisitationTrack_DomainId] ON [CustomerWebpageVisitationTrack] ([DomainId]);
GO

CREATE INDEX [IX_CustomerWebpageVisitationTrack_SiteId] ON [CustomerWebpageVisitationTrack] ([SiteId]);
GO

CREATE INDEX [IX_DialogMessage_CustomerId] ON [DialogMessage] ([CustomerId]);
GO

CREATE INDEX [IX_DialogMessage_DomainId] ON [DialogMessage] ([DomainId]);
GO

CREATE INDEX [IX_DialogMessage_SessionId] ON [DialogMessage] ([SessionId]);
GO

CREATE INDEX [IX_DialogMessage_SiteId] ON [DialogMessage] ([SiteId]);
GO

CREATE INDEX [IX_DialogMessage_StaffId] ON [DialogMessage] ([StaffId]);
GO

CREATE INDEX [IX_Dictionary_DomainId] ON [Dictionary] ([DomainId]);
GO

CREATE INDEX [IX_DictionaryItem_DictionaryId] ON [DictionaryItem] ([DictionaryId]);
GO

CREATE INDEX [IX_DictionaryItem_DomainId] ON [DictionaryItem] ([DomainId]);
GO

CREATE INDEX [IX_FavouriteFile_DomainId] ON [FavouriteFile] ([DomainId]);
GO

CREATE INDEX [IX_FavouriteFile_SiteId] ON [FavouriteFile] ([SiteId]);
GO

CREATE INDEX [IX_FavouriteFile_StaffId] ON [FavouriteFile] ([StaffId]);
GO

CREATE INDEX [IX_LeaveMessage_CustomerId] ON [LeaveMessage] ([CustomerId]);
GO

CREATE INDEX [IX_LeaveMessage_DomainId] ON [LeaveMessage] ([DomainId]);
GO

CREATE INDEX [IX_LeaveMessage_ProcessedStaffId] ON [LeaveMessage] ([ProcessedStaffId]);
GO

CREATE INDEX [IX_LeaveMessage_SiteId] ON [LeaveMessage] ([SiteId]);
GO

CREATE INDEX [IX_OpenApiCaller_DomainId] ON [OpenApiCaller] ([DomainId]);
GO

CREATE INDEX [IX_OpenApiCaller_SiteId] ON [OpenApiCaller] ([SiteId]);
GO

CREATE INDEX [IX_OpenApiCallLog_DomainId] ON [OpenApiCallLog] ([DomainId]);
GO

CREATE INDEX [IX_OpenApiCallLog_OpenApiCallerId] ON [OpenApiCallLog] ([OpenApiCallerId]);
GO

CREATE INDEX [IX_OpenApiCallLog_SiteId] ON [OpenApiCallLog] ([SiteId]);
GO

CREATE INDEX [IX_Organization_DomainId] ON [Organization] ([DomainId]);
GO

CREATE INDEX [IX_Organization_ParentId] ON [Organization] ([ParentId]);
GO

CREATE INDEX [IX_QuicklyReplyCategory_DomainId] ON [QuicklyReplyCategory] ([DomainId]);
GO

CREATE INDEX [IX_QuicklyReplyCategory_StaffId] ON [QuicklyReplyCategory] ([StaffId]);
GO

CREATE INDEX [IX_QuicklyReplyItem_DomainId] ON [QuicklyReplyItem] ([DomainId]);
GO

CREATE INDEX [IX_QuicklyReplyItem_QuicklyReplyCategoryId] ON [QuicklyReplyItem] ([QuicklyReplyCategoryId]);
GO

CREATE INDEX [IX_RobotExternalApiSettings_DomainId] ON [RobotExternalApiSettings] ([DomainId]);
GO

CREATE INDEX [IX_RobotExternalApiSettings_SiteId] ON [RobotExternalApiSettings] ([SiteId]);
GO

CREATE INDEX [IX_RobotItem_DomainId] ON [RobotItem] ([DomainId]);
GO

CREATE INDEX [IX_RobotItem_ParentId] ON [RobotItem] ([ParentId]);
GO

CREATE INDEX [IX_RobotItem_SiteId] ON [RobotItem] ([SiteId]);
GO

CREATE INDEX [IX_RobotSettings_DomainId] ON [RobotSettings] ([DomainId]);
GO

CREATE INDEX [IX_RobotSettings_SiteId] ON [RobotSettings] ([SiteId]);
GO

CREATE INDEX [IX_Role_DomainId] ON [Role] ([DomainId]);
GO

CREATE INDEX [IX_RoleAuthorization_DomainId] ON [RoleAuthorization] ([DomainId]);
GO

CREATE INDEX [IX_RoleAuthorization_RoleId] ON [RoleAuthorization] ([RoleId]);
GO

CREATE INDEX [IX_RoleStaff_DomainId] ON [RoleStaff] ([DomainId]);
GO

CREATE INDEX [IX_RoleStaff_RoleId] ON [RoleStaff] ([RoleId]);
GO

CREATE INDEX [IX_RoleStaff_StaffId] ON [RoleStaff] ([StaffId]);
GO

CREATE INDEX [IX_Session_CustomerId] ON [Session] ([CustomerId]);
GO

CREATE INDEX [IX_Session_DomainId] ON [Session] ([DomainId]);
GO

CREATE INDEX [IX_Session_SiteId] ON [Session] ([SiteId]);
GO

CREATE INDEX [IX_Session_SkillGroupId] ON [Session] ([SkillGroupId]);
GO

CREATE INDEX [IX_Session_StaffId] ON [Session] ([StaffId]);
GO

CREATE INDEX [IX_Site_DomainId] ON [Site] ([DomainId]);
GO

CREATE INDEX [IX_SiteLoginAppointedStaff_DomainId] ON [SiteLoginAppointedStaff] ([DomainId]);
GO

CREATE INDEX [IX_SiteLoginAppointedStaff_SiteId] ON [SiteLoginAppointedStaff] ([SiteId]);
GO

CREATE INDEX [IX_SiteLoginAppointedStaff_StaffId] ON [SiteLoginAppointedStaff] ([StaffId]);
GO

CREATE INDEX [IX_SiteSettings_AutoGreetings_DomainId] ON [SiteSettings_AutoGreetings] ([DomainId]);
GO

CREATE INDEX [IX_SiteSettings_AutoGreetings_SiteId] ON [SiteSettings_AutoGreetings] ([SiteId]);
GO

CREATE INDEX [IX_SiteSettings_CustomerFillInFieldBeforeStart_DomainId] ON [SiteSettings_CustomerFillInFieldBeforeStart] ([DomainId]);
GO

CREATE INDEX [IX_SiteSettings_CustomerFillInFieldBeforeStart_SiteId] ON [SiteSettings_CustomerFillInFieldBeforeStart] ([SiteId]);
GO

CREATE INDEX [IX_SiteSettings_CustomerUILanguage_DomainId] ON [SiteSettings_CustomerUILanguage] ([DomainId]);
GO

CREATE INDEX [IX_SiteSettings_CustomerUILanguage_SiteId] ON [SiteSettings_CustomerUILanguage] ([SiteId]);
GO

CREATE INDEX [IX_SiteSettings_FakeCustomerWaitingQueue_DomainId] ON [SiteSettings_FakeCustomerWaitingQueue] ([DomainId]);
GO

CREATE INDEX [IX_SiteSettings_FakeCustomerWaitingQueue_SiteId] ON [SiteSettings_FakeCustomerWaitingQueue] ([SiteId]);
GO

CREATE INDEX [IX_SiteSettings_LeaveMessageContentTemplate_DomainId] ON [SiteSettings_LeaveMessageContentTemplate] ([DomainId]);
GO

CREATE INDEX [IX_SiteSettings_LeaveMessageContentTemplate_SiteId] ON [SiteSettings_LeaveMessageContentTemplate] ([SiteId]);
GO

CREATE INDEX [IX_SiteSettings_MiniWebChat_DomainId] ON [SiteSettings_MiniWebChat] ([DomainId]);
GO

CREATE INDEX [IX_SiteSettings_MiniWebChat_SiteId] ON [SiteSettings_MiniWebChat] ([SiteId]);
GO

CREATE INDEX [IX_SiteSettings_Misc_DomainId] ON [SiteSettings_Misc] ([DomainId]);
GO

CREATE INDEX [IX_SiteSettings_Misc_SiteId] ON [SiteSettings_Misc] ([SiteId]);
GO

CREATE INDEX [IX_SiteSettings_Translation_DomainId] ON [SiteSettings_Translation] ([DomainId]);
GO

CREATE INDEX [IX_SiteSettings_Translation_SiteId] ON [SiteSettings_Translation] ([SiteId]);
GO

CREATE INDEX [IX_SiteSettings_WebChatMisc_DomainId] ON [SiteSettings_WebChatMisc] ([DomainId]);
GO

CREATE INDEX [IX_SiteSettings_WebChatMisc_SiteId] ON [SiteSettings_WebChatMisc] ([SiteId]);
GO

CREATE INDEX [IX_SiteSettings_WebChatOpeningGreetings_DomainId] ON [SiteSettings_WebChatOpeningGreetings] ([DomainId]);
GO

CREATE INDEX [IX_SiteSettings_WebChatOpeningGreetings_SiteId] ON [SiteSettings_WebChatOpeningGreetings] ([SiteId]);
GO

CREATE INDEX [IX_SiteSettings_WebChatStyle_DomainId] ON [SiteSettings_WebChatStyle] ([DomainId]);
GO

CREATE INDEX [IX_SiteSettings_WebChatStyle_SiteId] ON [SiteSettings_WebChatStyle] ([SiteId]);
GO

CREATE INDEX [IX_SiteSettings_WebLeaveMessage_DomainId] ON [SiteSettings_WebLeaveMessage] ([DomainId]);
GO

CREATE INDEX [IX_SiteSettings_WebLeaveMessage_SiteId] ON [SiteSettings_WebLeaveMessage] ([SiteId]);
GO

CREATE INDEX [IX_SiteSettings_WebPagePlugIn_DomainId] ON [SiteSettings_WebPagePlugIn] ([DomainId]);
GO

CREATE INDEX [IX_SiteSettings_WebPagePlugIn_SiteId] ON [SiteSettings_WebPagePlugIn] ([SiteId]);
GO

CREATE INDEX [IX_SkillGroup_DomainId] ON [SkillGroup] ([DomainId]);
GO

CREATE INDEX [IX_SkillGroup_SiteId] ON [SkillGroup] ([SiteId]);
GO

CREATE INDEX [IX_SkillGroupSettings_DomainId] ON [SkillGroupSettings] ([DomainId]);
GO

CREATE INDEX [IX_SkillGroupSettings_SiteId] ON [SkillGroupSettings] ([SiteId]);
GO

CREATE INDEX [IX_SkillGroupStaff_DomainId] ON [SkillGroupStaff] ([DomainId]);
GO

CREATE INDEX [IX_SkillGroupStaff_SkillGroupId] ON [SkillGroupStaff] ([SkillGroupId]);
GO

CREATE INDEX [IX_SkillGroupStaff_StaffId] ON [SkillGroupStaff] ([StaffId]);
GO

CREATE INDEX [IX_Staff_DomainId] ON [Staff] ([DomainId]);
GO

CREATE INDEX [IX_Staff_OrganizationId] ON [Staff] ([OrganizationId]);
GO

CREATE INDEX [IX_StaffClientWebPagePlugIn_DomainId] ON [StaffClientWebPagePlugIn] ([DomainId]);
GO

CREATE INDEX [IX_StaffClientWebPagePlugIn_SiteId] ON [StaffClientWebPagePlugIn] ([SiteId]);
GO

CREATE INDEX [IX_StaffLoginHistory_DomainId] ON [StaffLoginHistory] ([DomainId]);
GO

CREATE INDEX [IX_StaffLoginHistory_SiteId] ON [StaffLoginHistory] ([SiteId]);
GO

CREATE INDEX [IX_StaffLoginHistory_StaffId] ON [StaffLoginHistory] ([StaffId]);
GO

CREATE INDEX [IX_StaffPersonalSettings_MobileWebChatOpeningGreetings_DomainId] ON [StaffPersonalSettings_MobileWebChatOpeningGreetings] ([DomainId]);
GO

CREATE INDEX [IX_StaffPersonalSettings_MobileWebChatOpeningGreetings_SiteId] ON [StaffPersonalSettings_MobileWebChatOpeningGreetings] ([SiteId]);
GO

CREATE INDEX [IX_StaffPersonalSettings_MobileWebChatOpeningGreetings_StaffId] ON [StaffPersonalSettings_MobileWebChatOpeningGreetings] ([StaffId]);
GO

CREATE INDEX [IX_StaffPersonalSettings_Remind_DomainId] ON [StaffPersonalSettings_Remind] ([DomainId]);
GO

CREATE INDEX [IX_StaffPersonalSettings_Remind_StaffId] ON [StaffPersonalSettings_Remind] ([StaffId]);
GO

CREATE INDEX [IX_StaffPersonalSettings_WebChatOpeningGreetings_DomainId] ON [StaffPersonalSettings_WebChatOpeningGreetings] ([DomainId]);
GO

CREATE INDEX [IX_StaffPersonalSettings_WebChatOpeningGreetings_SiteId] ON [StaffPersonalSettings_WebChatOpeningGreetings] ([SiteId]);
GO

CREATE INDEX [IX_StaffPersonalSettings_WebChatOpeningGreetings_StaffId] ON [StaffPersonalSettings_WebChatOpeningGreetings] ([StaffId]);
GO

CREATE INDEX [IX_StaffSettings_Operation_DomainId] ON [StaffSettings_Operation] ([DomainId]);
GO

CREATE INDEX [IX_StaffSettings_Operation_StaffId] ON [StaffSettings_Operation] ([StaffId]);
GO

INSERT INTO [__EFMigrationsHistory] ([MigrationId], [ProductVersion])
VALUES (N'20250114110430_20250115a', N'8.0.11');
GO

COMMIT;
GO

BEGIN TRANSACTION;
GO

CREATE TABLE [SiteSettings_AI] (
    [Id] uniqueidentifier NOT NULL,
    [SiteId] uniqueidentifier NOT NULL,
    [Enabled] bit NOT NULL,
    [DomainId] uniqueidentifier NOT NULL,
    CONSTRAINT [PK_SiteSettings_AI] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_SiteSettings_AI_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE CASCADE,
    CONSTRAINT [FK_SiteSettings_AI_Site_SiteId] FOREIGN KEY ([SiteId]) REFERENCES [Site] ([Id]) ON DELETE CASCADE
);
GO

CREATE INDEX [IX_SiteSettings_AI_DomainId] ON [SiteSettings_AI] ([DomainId]);
GO

CREATE INDEX [IX_SiteSettings_AI_SiteId] ON [SiteSettings_AI] ([SiteId]);
GO

INSERT INTO [__EFMigrationsHistory] ([MigrationId], [ProductVersion])
VALUES (N'20250126055650_20250126a', N'8.0.11');
GO

COMMIT;
GO

